@@ -18,6 +18,8 @@ from shutil import copy
 from shutil import copytree
 from tempfile import mkdtemp
 
+from geo import BoundingBox
+
 try:
     import ogr
 except ImportError:
@@ -620,7 +622,7 @@ def get_sitecode_aoiwkt(geom_info, aoi_epsg):
     log.debug("aoi: {}".format(sitecode_geom_dict))
     return sitecode_geom_dict
 
-def get_sitecode_from_aoiwkt_parse(aoi_wkt, t_srs):
+def get_sitecode_from_aoiwkt_parse(aoi_wkt, t_srs, gpkg_folder_path):
     if aoi_wkt.endswith(".gpkg"):
        log.debug("aoi is specified as an gpkg file")
        aoi_ds = ogr.Open(aoi_wkt)
@@ -642,7 +644,7 @@ def get_sitecode_from_aoiwkt_parse(aoi_wkt, t_srs):
     else:
        aoi_geom = aoi_wkt
     if True:
-       compositing_grid = get_grid_file(t_srs)
+       compositing_grid = get_grid_file(t_srs, gpkg_folder_path)
        if compositing_grid["status"] == "OK":
           log.debug("grid geopackage:{}".format(compositing_grid["output"]))
           compositing_squares = get_composite_squares(aoi_geom, compositing_grid["output"])
@@ -704,13 +706,13 @@ def tile_aoi(geom_wkt):
     else:
         return False
 
-def get_grid_file(epsg_code):
+def get_grid_file(epsg_code, gpkg_folder_path):
     """
     Get absolute path to compositing grid file.
     :param epsg_code: EPSG code of target Spatial Reference System.
     :return: absolute path to compositing grid file.
     """
-    gridfile = os.path.abspath(os.path.join("/tondor/tiles_gpkgfiles", "{0}_withsitecode.gpkg".format(epsg_code)))
+    gridfile = os.path.abspath(os.path.join(str(gpkg_folder_path), "{0}_withsitecode.gpkg".format(epsg_code)))
     if os.path.isfile(gridfile):
         return {"status": "OK",
                 "output": gridfile}
@@ -762,8 +764,15 @@ def get_aoi_geometry(aoi_file, epsg_code):
         return {"status": "OK",
                 "output": geom.ExportToWkt()}
 
-def sitecode_extent(sitecode,  epsg_code):
-    gridfile = os.path.abspath(os.path.join("/tondor/tiles_gpkgfiles", "{0}_withsitecode.gpkg".format(epsg_code)))
+def sitecode_extent(sitecode,  epsg_code, gpkg_folder_path):
+    # fix me:
+    if 'CZTILE' in str(sitecode) and int(epsg_code) == 32633:
+       gridfile = os.path.abspath(os.path.join(str(gpkg_folder_path), "CZGRID.gpkg"))
+    elif 'CZTILE' in str(sitecode) and int(epsg_code) != 32633:
+       log.error("sitecode has CZTILE while epsg is not 32633. check it.")
+    else:
+       gridfile = os.path.abspath(os.path.join(str(gpkg_folder_path), "{0}_withsitecode.gpkg".format(epsg_code)))
+
     processing_tiles_ds = ogr.Open(gridfile)
     processing_tiles_lyr = processing_tiles_ds.GetLayer()
     processing_tiles_srs = processing_tiles_lyr.GetSpatialRef()
@@ -772,7 +781,13 @@ def sitecode_extent(sitecode,  epsg_code):
     for feature in processing_tiles_lyr:
 
         if feature['sitecode'] == sitecode:
-           return feature.geometry().ExportToWkt()
+            xmin = feature['xmin']
+            xmax = feature['xmax']
+            ymin = feature['ymin']
+            ymax = feature['ymax']
+            b_box_instance = BoundingBox(xmin, ymin, xmax, ymax, epsg_code)
+            b_box_instance_geom = b_box_instance.to_geom()
+            return b_box_instance_geom.ExportToWkt()
 
 #################################################################################################
 #################################################################################################
